@@ -24,7 +24,7 @@
 */
 
 /*
-    This programme will notify manage the devfs filesystem.
+    This programme will manage the devfs filesystem.
 
 
     Written by      Richard Gooch   9-AUG-1998
@@ -159,9 +159,12 @@
   to <get_old_name> in compat_name.c. Simplified <action_compat> for SCSI and
   IDE new compatibilty entries.
 
-    Last updated by Richard Gooch   10-JUN-2000: Moved version string to
+    Updated by      Richard Gooch   10-JUN-2000: Moved version string to
   version.h
 
+    Last updated by Richard Gooch   3-JUL-2000: Added "-C /etc/modules.devfs"
+  when calling modprobe(8). Fail if a configuration line has EXECUTE modprobe.
+
 
 */
 #include <unistd.h>
@@ -684,9 +687,12 @@ static void process_config_line (CONST char *line, unsigned long *event_mask)
     {
 	new->action.what = AC_EXECUTE;
 	num_args -= 3;
-	if (strstr (p[0], "modprobe") != NULL)  /*  Bitch and moan  */
+	if (strstr (p[0], "modprobe") != NULL)
+	{   /*  Bitch and moan  */
 	    SYSLOG (LOG_NOTICE,
-		    "PLEASE USE MODLOAD ACTION INSTEAD OF EXECUTE modprobe\n");
+		    "Use MODLOAD action instead of EXECUTE modprobe!\n");
+	    exit (1);
+	}
 	for (count = 0; count < num_args; ++count)
 	{
 	    if ( ( new->u.execute.argv[count] = strdup (p[count]) ) == NULL )
@@ -967,7 +973,7 @@ static void action_modload (const struct devfsd_notify_struct *info,
     [RETURNS] Nothing.
 */
 {
-    char *argv[4];
+    char *argv[6];
     char device[STRING_LENGTH];
     static int (*modprobe) (int argc, char **argv) = NULL;
     static flag first_time = TRUE;
@@ -982,13 +988,15 @@ static void action_modload (const struct devfsd_notify_struct *info,
     }
     argv[0] = "/sbin/modprobe";
     argv[1] = "-k";
-    argv[2] = device;
-    argv[3] = NULL;
+    argv[2] = "-C";
+    argv[3] = "/etc/modules.devfs";
+    argv[4] = device;
+    argv[5] = NULL;
     strcpy (device, "/dev/");
     strcpy (device + 5, info->devname);
     if (modprobe != NULL)
     {
-	(*modprobe) (3, argv);
+	(*modprobe) (5, argv);
 	return;
     }
     switch ( fork () )
